@@ -2,16 +2,16 @@
 #'
 #'@description Adds padding to the matrix
 #'
-#'@param heightmap A two-dimensional matrix, where each entry in the matrix is the elevation at that point. All points are assumed to be evenly spaced.
-#'@return Hillshade with edges padded
+#'@param input A two-dimensional matrix.
+#'@return Matrix with edges padded
 #'@keywords internal
-add_padding = function(heightmap) {
-  temp = matrix(0, nrow = nrow(heightmap) + 2, ncol = ncol(heightmap) + 2)
-  temp[2:(nrow(temp)-1), 2:(ncol(temp)-1)] = heightmap
-  temp[2:(nrow(temp)-1), 1] = heightmap[,1]
-  temp[1, 2:(ncol(temp)-1)] = heightmap[1,]
-  temp[2:(nrow(temp)-1), ncol(temp)] = heightmap[,ncol(heightmap)]
-  temp[nrow(temp), 2:(ncol(temp)-1)] = heightmap[nrow(heightmap),]
+add_padding = function(input) {
+  temp = matrix(0, nrow = nrow(input) + 2, ncol = ncol(input) + 2)
+  temp[2:(nrow(temp)-1), 2:(ncol(temp)-1)] = input
+  temp[2:(nrow(temp)-1), 1] = input[,1]
+  temp[1, 2:(ncol(temp)-1)] = input[1,]
+  temp[2:(nrow(temp)-1), ncol(temp)] = input[,ncol(input)]
+  temp[nrow(temp), 2:(ncol(temp)-1)] = input[nrow(input),]
   temp[1,1] = temp[1,2]
   temp[1,ncol(temp)] = temp[1,ncol(temp)-1]
   temp[nrow(temp),1] = temp[nrow(temp)-1,2]
@@ -23,36 +23,36 @@ add_padding = function(heightmap) {
 #'
 #'@description Adds multiple levels padding to the matrix
 #'
-#'@param heightmap A two-dimensional matrix, where each entry in the matrix is the elevation at that point. All points are assumed to be evenly spaced.
+#'@param input A two-dimensional matrix.
 #'@param pad Number of padding entries
-#'@return Hillshade with edges padded
+#'@return Matrix with edges padded
 #'@keywords internal
-add_multi_padding = function(heightmap, pad = 1) {
-  if(length(dim(heightmap)) == 2) {
-    temp = matrix(0, nrow = nrow(heightmap) + 2*pad, ncol = ncol(heightmap) + 2*pad)
-    temp[(1+pad):(pad + nrow(heightmap)), (1+pad):(pad+ncol(heightmap))] = heightmap
-    temp[(1+pad):(pad + nrow(heightmap)), 1:pad] = heightmap[,1]
+add_multi_padding = function(input, pad = 1) {
+  if(length(dim(input)) == 2) {
+    temp = matrix(0, nrow = nrow(input) + 2*pad, ncol = ncol(input) + 2*pad)
+    temp[(1+pad):(pad + nrow(input)), (1+pad):(pad+ncol(input))] = input
+    temp[(1+pad):(pad + nrow(input)), 1:pad] = input[,1]
     for(i in 1:pad) {
-      temp[i, (1+pad):(pad + ncol(heightmap))] = heightmap[1,]
+      temp[i, (1+pad):(pad + ncol(input))] = input[1,]
     }
-    for(i in (pad+ncol(heightmap)+1):ncol(temp)) {
-      temp[(1+pad):(pad+nrow(heightmap)), i] = heightmap[,ncol(heightmap)]
+    for(i in (pad+ncol(input)+1):ncol(temp)) {
+      temp[(1+pad):(pad+nrow(input)), i] = input[,ncol(input)]
     }
-    for(i in (pad+nrow(heightmap)+1):nrow(temp)) {
-      temp[i, (1+pad):(pad+ncol(heightmap))] = heightmap[nrow(heightmap),]
+    for(i in (pad+nrow(input)+1):nrow(temp)) {
+      temp[i, (1+pad):(pad+ncol(input))] = input[nrow(input),]
     }
-    temp[1:pad,1:pad] = heightmap[1,1]
-    temp[1:pad,(pad+ncol(heightmap)+1):ncol(temp)] = heightmap[1,ncol(heightmap)]
-    temp[(pad+nrow(heightmap)+1):nrow(temp),1:pad] = heightmap[nrow(heightmap),1]
-    temp[(pad+nrow(heightmap)+1):nrow(temp),(pad+ncol(heightmap)+1):ncol(temp)] = heightmap[nrow(heightmap),ncol(heightmap)]
+    temp[1:pad,1:pad] = input[1,1]
+    temp[1:pad,(pad+ncol(input)+1):ncol(temp)] = input[1,ncol(input)]
+    temp[(pad+nrow(input)+1):nrow(temp),1:pad] = input[nrow(input),1]
+    temp[(pad+nrow(input)+1):nrow(temp),(pad+ncol(input)+1):ncol(temp)] = input[nrow(input),ncol(input)]
     return(temp)
   } else {
     temp_height = list()
-    for(i in seq_len(dim(heightmap)[3])) {
-      temp_height[[i]] = add_multi_padding(heightmap[,,i], pad)
+    for(i in seq_len(dim(input)[3])) {
+      temp_height[[i]] = add_multi_padding(input[,,i], pad)
     }
-    temp_array = array(0,dim = c(dim(temp_height[[i]]), dim(heightmap)[3]))
-    for(i in seq_len(dim(heightmap)[3])) {
+    temp_array = array(0,dim = c(dim(temp_height[[i]]), dim(input)[3]))
+    for(i in seq_len(dim(input)[3])) {
       temp_array[,,i] = temp_height[[i]]
     }
     return(temp_array)
@@ -63,15 +63,15 @@ add_multi_padding = function(heightmap, pad = 1) {
 #'
 #'@description Trims padding
 #'
-#'@param heightmap A two-dimensional matrix, where each entry in the matrix is the elevation at that point. All points are assumed to be evenly spaced.
+#'@param input A two-dimensional matrix.
 #'@param pad Number of padding entries
-#'@return Hillshade with edges trimmed
+#'@return Matrix with edges trimmed
 #'@keywords internal
-trim_padding = function(heightmap, pad = 1) {
-  if(length(dim(heightmap)) == 2) {
-    return(heightmap[(1+pad):(nrow(heightmap)-pad), (1+pad):(ncol(heightmap)-pad)])
+trim_padding = function(input, pad = 1) {
+  if(length(dim(input)) == 2) {
+    return(input[(1+pad):(nrow(input)-pad), (1+pad):(ncol(input)-pad)])
   } else {
-    return(heightmap[(1+pad):(nrow(heightmap)-pad), (1+pad):(ncol(heightmap)-pad),])
+    return(input[(1+pad):(nrow(input)-pad), (1+pad):(ncol(input)-pad),])
   }
 }
 
