@@ -1,5 +1,8 @@
+#define STB_IMAGE_RESIZE_IMPLEMENTATION
+
 #include <RcppArmadillo.h>
 #include <RProgress.h>
+#include "stb_image_resize.h"
 // [[Rcpp::depends(RcppArmadillo)]]
 using namespace Rcpp;
 
@@ -33,15 +36,29 @@ arma::mat subsample(arma::mat& circle, int size) {
 }
 
 arma::mat subsample_interpolate(arma::mat& circle, float mag) {
+  //Create two vectors ranging from 1 to ncol/nrow
   arma::vec X = arma::regspace(1, circle.n_cols);
   arma::vec Y = arma::regspace(1, circle.n_rows);
+  //Create two vectors ranging from 1 to the ncol/nrow, with step mag
+  //e.g. (1 + 0*mag, 1 + mag, 1+2*mag, ... , 1 + floor(end-1)/mag, so that
+  // start + floor(end-1) * mag < ncol/nrow
+
+  //These are our new, interpolated values
   arma::vec XI = arma::regspace(X.min(), mag, X.max());
   arma::vec YI = arma::regspace(Y.min(), mag, Y.max());
+
+  //If X1.n_elem is even, remove one element to make it odd
   if(XI.n_elem % 2 == 0) {
     XI.set_size(XI.n_elem-1);
+  }
+  //If Y1.n_elem is even, remove one element to make it odd
+
+  if(YI.n_elem % 2 == 0) {
     YI.set_size(YI.n_elem-1);
   }
   arma::mat ZI;
+  //Interpolate the `circle` values given on the XY grid on the new grid ZI specified
+  //by XI and YI
   arma::interp2(X, Y, circle, XI, YI, ZI);
   return(ZI);
 }
@@ -76,6 +93,55 @@ arma::mat resize_image_xy(arma::mat& image, arma::vec XI, arma::vec YI) {
   return(ZI);
 }
 
+// [[Rcpp::export]]
+NumericMatrix resize_matrix_stb(NumericMatrix image, int width, int height, int method) {
+  float* resized_image = new float[width * height];
+  float* original_image = new float[image.ncol() * image.nrow()];
+
+  for(unsigned int i = 0; i < image.nrow(); i++ ) {
+    for(unsigned int j = 0; j < image.ncol(); j++) {
+      original_image[i + image.nrow() * j] = image(i,j);
+    }
+  }
+  stbir_filter interp_type;
+  switch(method) {
+    case 0:
+      interp_type = STBIR_FILTER_DEFAULT;
+      break;
+    case 1:
+      interp_type = STBIR_FILTER_BOX;
+      break;
+    case 2:
+      interp_type = STBIR_FILTER_TRIANGLE;
+      break;
+    case 3:
+      interp_type = STBIR_FILTER_CUBICBSPLINE;
+      break;
+    case 4:
+      interp_type = STBIR_FILTER_CATMULLROM;
+      break;
+    case 5:
+      interp_type = STBIR_FILTER_MITCHELL;
+      break;
+  default:
+    interp_type = STBIR_FILTER_MITCHELL;
+  }
+
+  stbir_resize_float_generic(original_image, image.nrow(), image.ncol(), 0,
+                             resized_image, width, height, 0,
+                             1, 0, 0, STBIR_EDGE_WRAP, interp_type, STBIR_COLORSPACE_LINEAR, NULL);
+  NumericMatrix resized_mat(width,height);
+  for(int i = 0; i < width; i++ ) {
+    for(int j = 0; j < height; j++) {
+      resized_mat(i,j) = resized_image[i + width * j];
+    }
+  }
+  delete[] resized_image;
+  delete[] original_image;
+
+  return(resized_mat);
+}
+
 float evaluate_disk(float x) {
   return((cos(x*1.685979) * -22.356787 + sin(x*1.685979) * 85.912460) * exp(-4.892608 *x) +
     (cos(x*4.998496) * 35.918936 + sin(x*4.998496) * -28.875618) * exp(-4.711870 *x) +
